@@ -15,7 +15,7 @@
  */
 
 #ifdef _MSC_VER
-#define _CRT_SECURE_NO_DEPRECATE
+#  define _CRT_SECURE_NO_DEPRECATE
 #endif
 
 #include <tcl.h>
@@ -24,17 +24,21 @@
 
 #include <stdio.h>
 #include <string.h>
+
 #ifdef HAVE_STDINT_H
-#include <stdint.h>
-#endif
-#ifdef HAVE_SYS_TYPES_H
-#    include <sys/types.h>
+#  include <stdint.h>
 #endif
 
+#ifdef HAVE_SYS_TYPES_H
+#  include <sys/types.h>
+#endif
+
+#include "int2ptr_ptr2int.h"
+
 #ifdef USE_NATIVE_POSTGRES
-#include <libpq-fe.h>
+#  include <libpq-fe.h>
 #else
-#include "fakepq.h"
+#  include "fakepq.h"
 #endif
 
 /* Include the files needed to locate htons() and htonl() */
@@ -42,43 +46,18 @@
 #ifdef _WIN32
 typedef int int32_t;
 typedef short int16_t;
-#define WIN32_LEAN_AND_MEAN
-#include <windows.h>
-#include <winsock2.h>
+#  define WIN32_LEAN_AND_MEAN
+#  include <windows.h>
+#  include <winsock2.h>
 #  ifdef _MSC_VER
-#   pragma comment (lib, "ws2_32")
+#    pragma comment (lib, "ws2_32")
 #  endif
 #else
-#include <netinet/in.h>
+#  include <netinet/in.h>
 #endif
 
 #ifdef _MSC_VER
-#define snprintf _snprintf
-#endif
-
-/*
- * Macros used to cast between pointers and integers (e.g. when storing an int
- * in ClientData), on 64-bit architectures they avoid gcc warning about "cast
- * to/from pointer from/to integer of different size".
- */
-
-#if !defined(INT2PTR) && !defined(PTR2INT)
-#   if defined(HAVE_INTPTR_T) || defined(intptr_t)
-#	define INT2PTR(p) ((void *)(intptr_t)(p))
-#	define PTR2INT(p) ((int)(intptr_t)(p))
-#   else
-#	define INT2PTR(p) ((void *)(p))
-#	define PTR2INT(p) ((int)(p))
-#   endif
-#endif
-#if !defined(UINT2PTR) && !defined(PTR2UINT)
-#   if defined(HAVE_UINTPTR_T) || defined(uintptr_t)
-#	define UINT2PTR(p) ((void *)(uintptr_t)(p))
-#	define PTR2UINT(p) ((unsigned int)(uintptr_t)(p))
-#   else
-#	define UINT2PTR(p) ((void *)(p))
-#	define PTR2UINT(p) ((unsigned int)(p))
-#   endif
+#  define snprintf _snprintf
 #endif
 
 /* Static data contained within this file */
